define(["app", "js/countModel","js/list/listView"], function(app, Count, ListView) {

	/**
	 * Bindings array. Bind DOM event to some handler function in controller
	 * @type {*[]}
	 */
	var bindings = [{
		element: '.count-add-link',
		event: 'click',
		handler: openAddPopup
	}, {
		element: '.list-panel-all',
		event: 'click',
		handler: showAll
	}, {
		element: '.list-panel-usds',
		event: 'click',
		handler: showUsds
	}, {
		element: '.list-panel-cups',
		event: 'click',
		handler: showCups
	}
	];

	var state = {
		isCup: true
	};

    function init() {
		var counts = loadCounts();
		ListView.render({
			bindings: bindings,
			model: counts
		});
	}

	function openAddPopup() {
		app.router.load('countEdit', { 'isCup': state.isCup });
	}

	function showUsds() {
		state.isCup = false;
		var counts = loadCounts({ isCup: false });
		ListView.reRender({ model: counts, header: "Conteos en USD" });
	}

	function showCups() {
		state.isCup = true;
		var counts = loadCounts({ isCup: true });
		ListView.reRender({ model: counts, header: "Conteos en CUP" });
	}

	function showAll() {
		var counts = loadCounts();
		ListView.reRender({ model: counts, header: "Conteos Realizados" });
	}

	function loadCounts(filter) {
		var f7Counts = localStorage.getItem("f7Counts");
		var counts = f7Counts ? JSON.parse(f7Counts) : tempInitializeStorage();
		if (filter) {
			counts = _.filter(counts, filter);
		}
		counts.sort(countSort);
		counts = _.groupBy(counts, function(count) { return count.countName.charAt(0); });
		counts = _.toArray(_.mapValues(counts, function(value, key) { return { 'letter': key, 'list': value }; }));
		return counts;
	}

	function tempInitializeStorage() {
		var counts = [

		];
		localStorage.setItem("f7Counts", JSON.stringify(counts));
		return JSON.parse(localStorage.getItem("f7Counts"));
	}

	function countSort(a, b) {
		if (a.countName > b.countName) {
			return 1;
		}
		if (a.countName === b.countName && a.countDate >= b.countDate) {
			return 1;
		}
		return -1;
	}

    return {
        init: init
    };
});
